$title	Single country model in MPSGE

*======================================================================================
$ontext
$model:gtap9

$sectors:
	y(g)$vomz(g) 		! Supply
	m(i)$vimz(i)		! Imports
	x(i)$vxz(i)		! Exports
	a(i)$(a0z(i) and not ele(i) and not tnd(i))	! Armington aggregation of domestic and imported varieties	
	a_e(i,g)$(varmz(i,g) and fe(i))	! Armington aggregation of domestic and imported varieties with CO2 emissions - fossil fossil fuels
	ele_s(i)$(d0z(i) and enfi(i))   ! Production block to allow electrcity from different sources to be perfect substitutes for each other
	ele_f$vele_df		! Agrregation of fossil fuel electricity generation	
	ele_a$velez		! Aggregate electricity and transmission and distribution
	ele_m$vele_m		! Aggregate electricity imports 
	ft(f,i)$vmfmz(f,i)	! Allocation of mobile factors to sectors
	ht_oil			! Fuel purchases for new cars
	ht_pt			! Powertrain purchases for new cars
	otran			! Own-supplied transportation
	tghg(nco2,g)$((policy("fclim") or policy("fctax")) and policy("fnco2") and fssclim(g) and oghg(nco2,g)*ghgmult(nco2,g) and vomz(g))	! Transformation function for non-CO2 GHGs
	tghg_2(nco2,g)$(policy("fclim_2") and policy("fnco2_2") and fssclim_2(g) and oghg(nco2,g)*ghgmult(nco2,g) and vomz(g))			! Transformation function for non-CO2 GHGs in a secondary policy
	tco2$policy("tco2")	! Trade amoung ETS Policies
	tco2_raw$(policy("fclim") or policy("fctax"))		! CO2 permit price - billions of dollars 2011$ per million metric tons  
	offsets$(policy("fclim") or policy("fctax") and policy("foffset"))	! Imports of international offsets
	w			! Welfare index

$commodities:
	p(g)$vomz(g)			! Domestic output price
	pm(j)$vimz(j)			! Import price
	px(g)$vx0z(g)			! Export price
	pa(i)$(a0z(i) and not ele(i) and not tnd(i))	! Armington aggregation price	
	pa_e(i,g)$(varmz(i,g) and fe(i))	! Armington aggregation price with CO2 emissions - if applicable - except for electricity
	pelec$velez			! Aggregate electricity with transmission and distribution
	pelec_s$velez			! Aggregate domestic electricity - without transmission and distribution
	pelec_m$vele_m			! Aggregate electricity imports - without T & D	
	pf(f)$evmfz(f)			! Mobile primary factors
	ps(f,g)$(vffmz(f,g)+vmfmz(f,g))	! Sector-specific primary factors
	ptsf(g)$vtsfz(g)		! Price of the technology specific factor
	pfx				! Price of foreign exchange
	pht_oil		! Price of fuel for new cars		
	pht_pt		! Price of powertrain for new cars
	ptran		! Price of own-supplied 
	pw				! Price of welfare index
	pco2$(policy("fclim") or policy("fctax"))		! CO2 permit price - billions of dollars 2011$ per million metric tons  
	pco2_raw$(policy("fclim") or policy("fctax"))		! CO2 permit price - billions of dollars 2011$ per million metric tons 
	pco2_2$policy("fclim_2")	! CO2 permit price for a secondary cap - billions of dollars 2011$ per million metric tons
	pco2cert$policy("limit_alpha")	! Price of CO2 certificates required for turning secondary ETS permits into primary ETS permits				
	pcertoff$policy("offset_prop")	! Price of CO2 certificates for turning international offsets into domestic permits
	pghg(nco2,g)$((policy("fclim") or policy("fctax")) and policy("fnco2") and fssclim(g) and oghg(nco2,g)*ghgmult(nco2,g))	! Price of non-CO2 GHGs
	pghg_2(nco2,g)$(policy("fclim_2") and policy("fnco2_2") and fssclim_2(g) and oghg(nco2,g)*ghgmult(nco2,g))	! Price of non-CO2 GHGs in a secondary policy
	prfs$policy("res")		! Renewable electricity permit price
	pht_permit$policy("f_fecon")	! Permit price used to enforce fuel economy standard

$consumers:
	ra			! Representative agent

$auxiliary:
	tau$cintflag						! Endogenous CO2 tax derived from CO2 intensity constraint
	tau_gdp$(gdpmult and not scenario("benchmark"))		! Endowment multiplier to target GDP in the reference scenario
	tau_ff(g)$(ffprice(g) and evffmz("res",g) and not scenario("benchmark"))	! Endogonous multiplier on fossil fuel resources to calibrate to pre-determined prices
	tau_ctax$policy("ctax")				! Endogonous multiplier on CO2 permits to target a CO2 tax
	tau_part$(policy("pets") and policy("clim"))	! Endogenous multiplier on covered sector emissions to target a broader emissions reduction

*	All production except electricity, fossil fuel extraction, agriculture, and consumption
$prod:y(g)$(vomz(g) and not elea(g) and not xe(g) and not agr(g) and not cons(g)) t:etrne(g) s:esubghg(g) s2:esub(g) kle(s):sigma("kle")  va(kle):esubva(g)
+	e(kle):sigma("ele_ne")  ne(e):sigma("ne")
	o:px(g)$vx0z(g)		q:vx0z(g)		a:ra  t:rtoz(g)
	o:p(g)			q:(vomz(g)-vx0z(g))	a:ra  t:rtoz(g)
	i:pa(i)$(not fte(i))	q:varmz(i,g)			s2:
	i:pelec			q:velea(g)			e:
	i:pa_e(fe,g)		q:varmz(fe,g)			ne:
	i:ps(f,g)		q:(vffmz(f,g)+vmfmz(f,g))	p:(1+rtf0z(f,g))  va:    a:ra t:rtfz(f,g)
	i:pghg(nco2,g)$((policy("fclim") or policy("fctax")) and policy("fnco2") and fssclim(g))	q:(oghg(nco2,g)*ghgmult(nco2,g))	p:1e-5
	i:pghg_2(nco2,g)$(policy("fclim_2") and policy("fnco2_2") and fssclim_2(g))	q:(oghg(nco2,g)*ghgmult(nco2,g))		p:1e-5

*	Agriculture
$prod:y(g)$(vomz(g) and agr(g))	t:etrne(g) s:esubghg(g)  rkl:sigma("rkl")  va(rkl):esubva(g)  res(rkl):sigma("lem") em(res):0
+	e(em):sigma("ele_ne")  ne(e):sigma("ne")
	o:px(g)$vx0z(g)		q:vx0z(g)		a:ra  t:rtoz(g)
	o:p(g)			q:(vomz(g)-vx0z(g))	a:ra  t:rtoz(g)
	i:pa(i)$(not fte(i))	q:varmz(i,g)	em:
	i:pelec			q:velea(g)	e:
	i:pa_e(fe,g)		q:varmz(fe,g)	ne:
	i:ps(f,g)$(not (sameas(f,"lnd") or sameas(f,"res")))	q:(vffmz(f,g)+vmfmz(f,g))	p:(1+rtf0z(f,g))  va:    a:ra t:rtfz(f,g)
	i:ps(f,g)$(sameas(f,"lnd") or sameas(f,"res"))		q:(vffmz(f,g)+vmfmz(f,g))	p:(1+rtf0z(f,g))  res:    a:ra t:rtfz(f,g)
	i:pghg(nco2,g)$((policy("fclim") or policy("fctax")) and policy("fnco2") and fssclim(g))	q:(oghg(nco2,g)*ghgmult(nco2,g))	p:1e-5
	i:pghg_2(nco2,g)$(policy("fclim_2") and policy("fnco2_2") and fssclim_2(g))	q:(oghg(nco2,g)*ghgmult(nco2,g))		p:1e-5

*	Fossil fuel extraction
$prod:y(xe)$vomz(xe) t:etrne(xe) s:esubghg(xe) s2:esub_es(xe)  klo(s2):0  va(klo):esubva(xe)
	o:px(xe)$vx0z(xe)	q:vx0z(xe)		a:ra  t:rtoz(xe)
	o:p(xe)			q:(vomz(xe)-vx0z(xe))	a:ra  t:rtoz(xe)
	i:pa(i)$(not fte(i))	q:varmz(i,xe)	klo:
	i:pa_e(fe,xe)		q:varmz(fe,xe)			klo:
	i:pelec			q:velea(xe)			klo:
	i:ps(f,xe)$(not res(f))	q:(vffmz(f,xe)+vmfmz(f,xe))	p:(1+rtf0z(f,xe))  va:   a:ra t:rtfz(f,xe)
	i:ps("res",xe)		q:vffmz("res",xe)		p:(1+rtf0z("res",xe))	s2:	a:ra t:rtfz("res",xe)
	i:pghg(nco2,xe)$((policy("fclim") or policy("fctax")) and policy("fnco2") and fssclim(xe))	q:(oghg(nco2,xe)*ghgmult(nco2,xe))	p:1e-5
	i:pghg_2(nco2,xe)$(policy("fclim_2") and policy("fnco2_2") and fssclim_2(xe))	q:(oghg(nco2,xe)*ghgmult(nco2,xe))			p:1e-5

*	Electricity generation from sectors without technology specific factors
$prod:y(g)$(vomz(g) and efos(g)) t:etrne(g)  s:esubghg(g) s2:0  kle(s2):sigma("e_kle") ne(kle):sigma("ne")  va(kle):esubva(g) 
        o:px(g)$vx0z(g)		q:vx0z(g)      		a:ra  t:rtoz(g)
	o:p(g)			q:(vomz(g)-vx0z(g))	a:ra  t:rtoz(g)
	o:prfs$policy("res")	q:evdpz(g)$fres(g)
	i:pa(i)$(not fte(i))	q:(varmz(i,g)*ecost(g))	s2:
	i:pelec			q:velea(g)	s2:
	i:prfs$policy("res")	q:(policy("res")*evdpz(g))$elea(g) 	s2:
	i:pa_e(fe,g)		q:varmz(fe,g)				ne:
        i:ps(f,g)		q:((vffmz(f,g)+vmfmz(f,g))*ecost(g))	p:(1+rtf0z(f,g))  va:    a:ra t:rtfz(f,g)
	i:pghg(nco2,g)$((policy("fclim") or policy("fctax")) and policy("fnco2") and fssclim(g))	q:(oghg(nco2,g)*ghgmult(nco2,g))	p:1e-5
	i:pghg_2(nco2,g)$(policy("fclim_2") and policy("fnco2_2") and fssclim_2(g))	q:(oghg(nco2,g)*ghgmult(nco2,g))		p:1e-5

*	Electricity generation from sectors with technology specific factors
$prod:y(g)$(vomz(g) and etsf(g)) t:etrne(g) s:0 s2:sigma(g) b(s2):0  kle(b):sigma("kle") ne(kle):sigma("ne")  va(kle):esubva(g) 
        o:px(g)$vx0z(g)		q:vx0z(g)      		a:ra  t:rtoz(g)
	o:p(g)			q:(vomz(g)-vx0z(g))	a:ra  t:rtoz(g)
	o:prfs$policy("res")	q:evdpz(g)$fres(g)
	i:ptsf(g)$vtsfz(g)	q:vtsfz(g)	p:(1+rtf0z("cap",g)) s2: a:ra t:rtfz("cap",g)
	i:pa(i)$(not fte(i))	q:(varmz(i,g)*ecost(g))	b:
	i:pelec			q:(velea(g)*ecost(g))	b:
	i:prfs$policy("res")	q:(policy("res")*evdpz(g))$elea(g) 
	i:pa_e(fe,g)		q:(varmz(fe,g)*ecost(g))			ne:
        i:ps(f,g)		q:((vffmz(f,g)+vmfmz(f,g))*ecost(g))	p:(1+rtf0z(f,g))  va:    a:ra t:rtfz(f,g)
	i:pghg(nco2,g)$((policy("fclim") or policy("fctax")) and policy("fnco2") and fssclim(g))	q:(oghg(nco2,g)*ghgmult(nco2,g))	p:1e-5
	i:pghg_2(nco2,g)$(policy("fclim_2") and policy("fnco2_2") and fssclim_2(g))	q:(oghg(nco2,g)*ghgmult(nco2,g))		p:1e-5

*	Aggregate electricity with transmission and distribution
$prod:ele_a$velez	s:sigma("elec_tnd") e_a(s):sigma("elec_a") tnd(s):0 
	o:pelec		q:velez
	i:pelec_s	q:(vele_d*aeei_ely("ecoa"))	e_a:
	i:pelec_m	q:(vele_m*aeei_ely("ecoa"))	e_a:	
	i:p(i)$tnd(i)	q:(d0z(i)*aeei_ely("ecoa"))	p:(1+t_dz(i))	tnd:	a:ra	t:t_dz(i)
	i:pm(i)$tnd(i)	q:(m0z(i)*aeei_ely("ecoa"))	p:(1+t_mz(i))	tnd:	a:ra	t:t_mz(i)

*	Allow electricity with technology specific factors to be perfect substitutes for each other (and fossil fuel electricity)
$prod:ele_s(i)$(d0z(i) and enfi(i))
	o:pelec_s	q:vele_dnf(i)
	i:p(i)		q:d0z(i)	p:(1+t_dz(i))	a:ra	t:t_dz(i)

*	Agrregation of fossil fuel electricity
$prod:ele_f$vele_df	s:sigma("ele_fos")
	o:pelec_s	q:vele_df
	i:p(i)$efosi(i)	q:a0z(i) q:d0z(i)	p:(1+t_dz(i))	a:ra	t:t_dz(i)

*	Government consumption ("g") and investment ("i")
$prod:y(g)$(vomz(g) and cons(g) and not sameas("c",g))  s:esub(g) ene(s):sigma("ene_fd")
	o:px(g)$vx0z(g)		q:vx0z(g)		a:ra  t:rtoz(g)
	o:p(g)			q:(vomz(g)-vx0z(g))	a:ra  t:rtoz(g)
	i:pa(i)$(not fte(i))	q:varmz(i,g)	
	i:pa_e(fe,g)		q:varmz(fe,g)			ene:
	i:pelec			q:velea(g)			ene:
	i:pghg(nco2,g)$((policy("fclim") or policy("fctax")) and policy("fnco2") and fssclim(g))	q:(oghg(nco2,g)*ghgmult(nco2,g))	p:1e-5
	i:pghg_2(nco2,g)$(policy("fclim_2") and policy("fnco2_2") and fssclim_2(g))	q:(oghg(nco2,g)*ghgmult(nco2,g))		p:1e-5

*	Private consumption ("c")
$prod:y(g)$(vomz(g) and sameas("c",g))  s:esub(g) b(s):sigma("e_ne_fd") ne(b):sigma("ne_fd") ene(b):sigma("ene_fd") tn(s):ehht("trn")
	o:px(g)$vx0z(g)		q:vx0z(g)		a:ra  t:rtoz(g)
	o:p(g)			q:(vomz(g)-vx0z(g))	a:ra  t:rtoz(g)
	i:pa(i)$(not fte(i) and not trn(i) and not sameas("mvh",i))	q:varmz(i,g)	ne:
	i:pa_e(fe,g)$(not sameas("oil",fe))	q:varmz(fe,g)				ene:
	i:pa_e(fe,g)$sameas("oil",fe)		q:vnhhtz("oil")				ene:
	i:pelec			q:velea(g)						ene:
	i:ptran			q:(tran_y("mult")*(vhhtz("output","old") + vhhtz("output","new"))) tn:
	i:pa(i)$trn(i)		q:varmz(i,g) tn:
	i:pghg(nco2,g)$((policy("fclim") or policy("fctax")) and policy("fnco2") and fssclim(g))	q:(oghg(nco2,g)*ghgmult(nco2,g))	p:1e-5
	i:pghg_2(nco2,g)$(policy("fclim_2") and policy("fnco2_2") and fssclim_2(g))	q:(oghg(nco2,g)*ghgmult(nco2,g))		p:1e-5

*	Own-supplied transportation - next three production blocks
*	Fuel used in new cars
$prod:ht_oil	s:0
	o:pht_oil		q:vhhtz("oil","new")
	i:pa_e("oil","c")	q:(vhhtz("oil","new")*aeei("oil","c_old"))
	i:pht_permit$policy("f_fecon")	q:(tran_inputsz("alpha")*vhhtz("oil","new"))

*	Powertrain in new cars
$prod:ht_pt	s:0
	o:pht_permit$policy("f_fecon")	q:vhhtz("pt","new")
	o:pht_pt	q:vhhtz("pt","new")
	i:pa("mvh")	q:vhhtz("pt","new")
	i:pht_permit$policy("f_fecon")	q:(tran_inputsz("alpha")*vhhtz("pt","new"))

*	Private (own-supplied) transportation
$prod:otran	s:ehht("o_n")	b:0 c:0 d(c):ehht("pt_oil")
	o:ptran		q:(vhhtz("output","old") + vhhtz("output","new"))
	i:pa_e("oil","c")	q:(vhhtz("oil","old")*aeei("oil","c_old"))		b:
	i:pa("ser")	q:vhhtz("ser","old")	b:
	i:pa("mvh")	q:vhhtz("npt","new")	c:
	i:pa("ser")	q:vhhtz("ser","new")	c:
	i:pht_pt	q:vhhtz("pt","new")	d:
	i:pht_oil	q:vhhtz("oil","new")	d:

$prod:a_e(i,g)$(varmz(i,g) and fe(i))	s:0	
	o:pa_e(i,g)					q:varmz(i,g)
	i:pa(i)						q:(varmz(i,g)*aeei(i,g))	
	i:pco2$((policy("fclim") or policy("fctax")) and fssclim(g))	q:(eco2az(i,g)*aeei(i,g))	p:1e-5
	i:pco2_2$(policy("fclim_2") and fssclim_2(g)) q:(eco2az(i,g)*aeei(i,g))				p:1e-5

*	Armington aggregate	
$prod:a(i)$(a0z(i) and not ele(i) and not tnd(i))	s:esuba(i)	
	o:pa(i)		q:a0z(i)	
	i:p(i)		q:d0z(i)	p:(1+t_dz(i)) a:ra	t:t_dz(i) 
	i:pm(i)		q:m0z(i)	p:(1+t_mz(i)) a:ra	t:t_mz(i)

*	Aggregate electricity imports without transmission and distribution
$prod:ele_m$vele_m	s:sigma("elec_m")	
	o:pelec_m	q:vele_m
	i:pm(i)$ele(i)	q:m0z(i)	p:(1+t_mz(i))	a:ra	t:t_mz(i)
	
*	Imports - except fossil fuels
$prod:m(i)$vimz(i)
	o:pm(i)	q:vimz(i)				
	i:pfx	q:(ffmult(i)*(vmmdz(i)+sum(j,vtwrz(j,i))))	p:pvmmdz(i) a:ra t:rtmsz(i) 

*	Exports
$prod:x(i)$vxz(i)
	o:pfx		q:(ffmult(i)*vxz(i))
	i:px(i)		q:(vxmdz(i)+vstz(i)) p:(1-rtxs0z(i)) a:ra t:(-rtxsz(i))

*	Assignment of mobile factors to sectors
$prod:ft(f,i)$vmfmz(f,i)
	o:ps(f,i)	q:vmfmz(f,i)
	i:pf(f)		q:vmfmz(f,i)

*	Welfare/utlity function	
$prod:w	s:0
	o:pw		q:(vomz("c")+vomz("g")+vomz("i"))
	i:p("c")	q:vomz("c")
	i:p("g")	q:vomz("g")
	i:p("i")	q:vomz("i")

*	Transformation funcutions for non-CO2 GHGs - needed to track non-CO2 emissions endoegnously
$prod:tghg(nco2,g)$((policy("fclim") or policy("fctax")) and policy("fnco2") and fssclim(g) and oghg(nco2,g)*ghgmult(nco2,g))
	o:pghg(nco2,g)	q:(oghg(nco2,g)*ghgmult(nco2,g))	
	i:pco2		q:(oghg(nco2,g)*ghgmult(nco2,g))	

$prod:tghg_2(nco2,g)$(policy("fclim_2") and policy("fnco2_2") and fssclim_2(g) and oghg(nco2,g)*ghgmult(nco2,g))
	o:pghg_2(nco2,g)	q:(oghg(nco2,g)*ghgmult(nco2,g))	
	i:pco2_2		q:(oghg(nco2,g)*ghgmult(nco2,g))	
	
$prod:tco2$policy("tco2")
	o:pco2					q:1
	i:pco2_2				q:1
	i:pco2cert$policy("limit_alpha")	q:1

$prod:tco2_raw$(policy("fclim") or policy("fctax"))
	o:pco2cert$policy("limit_alpha")	q:policy("limit_alpha")
	o:pcertoff$policy("offset_prop")	q:(policy("limit_alpha")*policy("offset_prop"))
	o:pco2					q:1
	i:pco2_raw				q:1

*	Specify international offsets
*	If limited, international offsets require inputs of "outside" permits and international permits
$prod:offsets$(policy("fclim") or policy("fctax") and policy("foffset"))
	o:pco2			q:policy("qoffset")
	i:pcertoff$(policy("limit_alpha") and policy("offset_prop"))	q:policy("qoffset")
	i:pco2cert$policy("limit_alpha")				q:policy("qoffset")
	i:pfx								q:1

*	Endowments and demand
$demand:ra
	d:pw				q:(vomz("c")+vomz("g")+vomz("i"))
	e:pfx				q:vbz		r:tau_gdp$(not scenario("benchmark"))
*	Sector specific fossil fuel resources
	e:ps(res,xe)			q:evffmz(res,xe)	r:tau_ff(xe)$(ffprice(xe) and evffmz("res",xe) and not scenario("benchmark"))
*	Other sector specific factors
*	Other resources in non-agricultural sectors	
	e:ps(res,g)$(not xe(g) and not agr(g))		q:evffmz(res,g)	r:tau_gdp$(not scenario("benchmark"))
*	Resources in agricultural sectors	
	e:ps(res,g)$agr(g)		q:(evffmz(res,g)*yield(res,g))	
*	Land in agricultural (all) sectors
	e:ps(lnd,g)			q:(evffmz(lnd,g)*yield(lnd,g))	
*	Other sector specific sectors	
	e:ps(f,g)$(not res(f) and not lnd(f))	q:evffmz(f,g)	r:tau_gdp$(not scenario("benchmark"))
	e:pf(f)				q:evmfz(f)	r:tau_gdp$(not scenario("benchmark"))
	e:ptsf(g)$vtsfz(g)		q:(evtsfz(g)*tsfmult(g))	
	e:pco2_raw$(policy("fclim") or policy("fctax"))		q:(policy("clim")+policy("fctax"))	r:tau$cintflag	r:tau_ctax$policy("fctax") r:tau_part$(policy("pets") and policy("clim"))	
	e:pco2_2$policy("fclim_2")	q:policy("clim_2")	

$REPORT:
*	INTERMEDIATE DEMANDS
*	Fossil fuels
	V:VARMZFE_R(fe,g)	i:pa(fe)	Prod:a_e(fe,g)
*	All goods except fossil fuels and electricity
	V:VARMZ_R(i,g)		I:pa(i)		Prod:y(g)
*	Aggregate electricity including transmission & distribution	
	V:VELEA_R(g)		I:pelec		Prod:y(g)
*	Domestic Electricity by type into aggregate electricity
*	Non-fossil electricity
	V:VELE_NF(i)		i:p(i)		Prod:ele_s(i)
*	Fossil electricity
	V:VELE_F(i)$d0z(i)	i:p(i)		Prod:ele_f
*	Imported electricity
	V:VELE_M_R(i)		i:pm(i)		Prod:ele_m
*	Domestic Use and Exports of Final Output
	V:VD0Z_R(g)$(vomz(g)-vx0z(g))	O:p(g)	Prod:y(g)	
	V:VX0Z_R(g)$vx0z(g)		O:px(g)	Prod:y(g)
*	Domestic and Imported Constituents to Armington Aggregates
	V:D0Z_R(i)$d0z(i)	I:p(i)	Prod:a(i)
	V:M0Z_R(i)$m0z(i)	I:pm(i)	Prod:a(i)
*	Armingtion aggregate
	V:A0Z_R(i)	o:pa(i)	Prod:a(i)
*	Non-CO2 GHGs included in the cap-and-trade policy
	V:nonco2(nco2,g)	o:pghg(nco2,g)		Prod:tghg(nco2,g)
*	Non-CO2 GHGs included in the secondary cap-and-trade policy
	V:nonco2_2(nco2,g)	o:pghg_2(nco2,g)	Prod:tghg_2(nco2,g)
*	Permits trade from the secondary to the promary	ETS
	V:tradeco2		o:pco2			Prod:tco2
*	Armington inputs by sector after aeei adjustments (if applicable)
*	Carbon Emission
	V:SCED(cs,g)	I:pco2		Prod:a_e(cs,g)

*	Household transportation reporting
*	Fuel used in new cars
	V:RPHT_OIL	i:pa_e("oil","c")	Prod:ht_oil
	V:RPHT_OIL2	i:pht_oil		Prod:otran
*	Non-powertrain capital in new cars - can use as an index for new car production as used in fixed proportion with output
	V:RPHT_NPT	i:pa("mvh")		Prod:otran
*	Powertrain capital in new cars
	V:RPHT_PT	i:pa("mvh")		Prod:ht_pt	
*	Motorvehcile (non-powertrain) purchases in new car expenditure - fixed proportion of output
	V:RMVH		i:pa("mvh")		Prod:otran
$CONSTRAINT:tau$cintflag
tau =e= 1;

$CONSTRAINT:tau_gdp$(gdpmult and scenario("reference") and not scenario("benchmark"))
(y("c")*vomz("c") + y("i")*vomz("i") + y("g")*vomz("g"))/(vomz("c")+vomz("i")+vomz("g")) =e= gdpmult;

$CONSTRAINT:tau_gdp$(gdpmult and scenario("policy") and not scenario("benchmark"))
tau_gdp =e= gdpbase;

$CONSTRAINT:tau_ff(g)$(ffprice(g) and evffmz("res",g) and scenario("reference"))
p(g) =e= ffprice(g);

$CONSTRAINT:tau_ff(g)$(ffprice(g) and scenario("policy"))
tau_ff(g) =e= ffmult_ref(g);

$CONSTRAINT:tau_ctax$policy("fctax")
pco2 =e= policy("ctax");

*	Constraint to target a broader emissions reduction from a sectoral policy
$CONSTRAINT:tau_part$(policy("pets") and policy("clim"))
* All CO2 emissions
sum((fe,g),a_e(fe,g)*eco2az(fe,g)*aeei(fe,g))
* Non-CO2 emissions from covered sectors
+ sum((nco2,g)$(oghg(nco2,g)*ghgmult(nco2,g) and fssclim(g)),tghg(nco2,g)*oghg(nco2,g)*ghgmult(nco2,g))$policy("fnco2")
* Non-CO2 emissoins from sectors covered by the secondary policy
+ sum((nco2,g)$(oghg(nco2,g)*ghgmult(nco2,g) and fssclim_2(g)),tghg_2(nco2,g)*oghg(nco2,g)*ghgmult(nco2,g))$policy("fnco2_2")
* Non-CO2 emissoins from uncovered sectors
+ sum((nco2,g)$(fssclim(g)*policy("fnco2") eq 0 and fssclim_2(g)*policy("fnco2_2") eq 0 and vomz(g)),Y(g)*oghg(nco2,g)*ghgmult(nco2,g))
* International offsets (subtract)
- (offsets*policy("qoffset"))$policy("foffset") =e= policy("clim");
$offtext

$sysinclude mpsgeset gtap9
p.fx("c") = 1;

*==============================================================================
*	Solve the model and store results
*==============================================================================

tau_ff.l(g) = 1;
tau_ff.lo(g) = 0.00001;
tau_ctax.l = 1;
tau_part.l = 0.05;
tau_part.lo = 0.0001;

gtap9.workspace = 128;
gtap9.iterlim$scenario("benchmark") = 0;
gtap9.iterlim$(scenario("benchmark") eq 0) = 1000;
$include gtap9.gen
solve gtap9 using mcp;

gtap9.iterlim = 15000;
$include gtap9.gen
solve gtap9 using mcp;

GDP = y.L("c")*vomz("c") + y.L("g")*vomz("g") + y.L("i")*vomz("i");
Welfare = vomz("c")*y.l("c");

Emissions("co2",g)		= sum(fe$varmz(fe,g),eco2az(fe,g)*VARMZFE_R.L(fe,g)/varmz(fe,g));
Emissions("co2","Covered sectors") = sum((fe,g)$(varmz(fe,g) and fssclim(g)),eco2az(fe,g)*VARMZFE_R.L(fe,g)/varmz(fe,g));
Emissions("co2","Elec. & energy intenistive") = sum((fe,g)$(varmz(fe,g) and feint(g)),eco2az(fe,g)*VARMZFE_R.L(fe,g)/varmz(fe,g));
Emissions("co2","Other sectors") = sum((fe,g)$(varmz(fe,g) and not feint(g)),eco2az(fe,g)*VARMZFE_R.L(fe,g)/varmz(fe,g));
Emissions("co2","Secondary policy") = sum((fe,g)$(varmz(fe,g) and fssclim_2(g)),eco2az(fe,g)*VARMZFE_R.L(fe,g)/varmz(fe,g));
Emissions("co2","Uncovered sectors") = sum((fe,g)$(varmz(fe,g) and fssclim(g) eq 0 and fssclim_2(g) eq 0),eco2az(fe,g)*VARMZFE_R.L(fe,g)/varmz(fe,g));

Emissions("co2","Total")	= sum((fe,g)$varmz(fe,g),eco2az(fe,g)*VARMZFE_R.L(fe,g)/varmz(fe,g));

Emissions(nco2,g)$(policy("fnco2") eq 0 or fssclim(g) eq 0) = Y.l(g)*oghg(nco2,g)*ghgmult(nco2,g);	
Emissions(nco2,g)$(policy("fnco2_2") eq 0 or fssclim_2(g) eq 0) = Y.l(g)*oghg(nco2,g)*ghgmult(nco2,g);	

Emissions(nco2,g)$(policy("fnco2") and fssclim(g) and vomz(g)) = nonco2.l(nco2,g);
Emissions(nco2,g)$(policy("fnco2_2") and fssclim_2(g) and vomz(g)) = nonco2_2.l(nco2,g);

Emissions(nco2,"Total") = sum(g,Emissions(nco2,g));
Emissions(nco2,"Covered sectors") = sum(g$fssclim(g),Emissions(nco2,g));
Emissions(nco2,"Elec. & energy intenistive") = sum(g$feint(g),Emissions(nco2,g));
Emissions(nco2,"Other sectors") = sum(g$(not feint(g)),Emissions(nco2,g));
Emissions(nco2,"Secondary policy") = sum(g$fssclim_2(g),Emissions(nco2,g));
Emissions(nco2,"Uncovered sectors") = sum(g$(fssclim(g) eq 0 and fssclim_2(g) eq 0),Emissions(nco2,g));

Emissions("Total",g) = sum(ghg,Emissions(ghg,g));
Emissions("Total","Covered sectors") = sum(ghg,Emissions(ghg,"Covered sectors"));
Emissions("Total","Elec. & energy intenistive") = sum(ghg,Emissions(ghg,"Elec. & energy intenistive"));
Emissions("Total","Other sectors") = sum(ghg,Emissions(ghg,"Other sectors"));
Emissions("Total","Secondary policy") = sum(ghg,Emissions(ghg,"Secondary policy"));
Emissions("Total","Uncovered sectors") = sum(ghg,Emissions(ghg,"Uncovered sectors"));
Emissions("Total","Total") = sum(ghg,Emissions(ghg,"Total"));
Emissions("Total","International offsets")$policy("foffset") = - offsets.l*policy("qoffset");
Emissions("Total","Net emissions") = Emissions("Total","Total") - (offsets.l*policy("qoffset"))$policy("foffset");

Emissbyfuel(fe,g)$varmz(fe,g)	= eco2az(fe,g)*VARMZFE_R.L(fe,g)/varmz(fe,g);
Emissbyfuel(fe,"Total")		= sum(g$varmz(fe,g),eco2az(fe,g)*VARMZFE_R.L(fe,g)/varmz(fe,g));

Electricity(elea)$vomz(elea)	= mtoe_TWh*evdpz(elea)*(VD0Z_R.l(elea)+VX0Z_R.l(elea))/(vomz(elea));
Electricity("Total")	= mtoe_TWh*sum(elea$vomz(elea),evdpz(elea)*(VD0Z_R.l(elea)+VX0Z_R.l(elea))/(vomz(elea)));

Elec_cons(ele)$a0z(ele)	= mtoe_TWh*(evazt(ele)*VELE_NF.L(ele)/a0z(ele) + evazt(ele)*VELE_F.L(ele)/a0z(ele));
Elec_cons("Total")	= mtoe_TWh*sum(ele$a0z(ele),evazt(ele)*VELE_NF.L(ele)/a0z(ele) + evazt(ele)*VELE_F.L(ele)/a0z(ele));

$ontext
Note: Primary energy calculations for electricity from wind, hydro, solar and nuclear follow the "Physical energy content method"
Primary energy from nuclear is based on the amount of heat generated in reactors. A conversion efficiency of 33% is assumed
For wind, solar and hydro, the primary energy equivalent is the physical energy content of electricity generated, which amounts to assuming an efficiency of 100%
See http://www.iea.org/statistics/resources/questionnaires/faq/#one
$offtext

evaz(fe,g) = co2scale(fe,g)*evaz(fe,g);

*	Fossil primary enegry
PrimEnergy(fe) = sum(g$varmz(fe,g),evaz(fe,g)*VARMZFE_R.L(fe,g)/varmz(fe,g));
*	Non-fossil primary energy, except nuclear 
PrimEnergy(enfi)$(not sameas(enfi,"enuc") and a0z(enfi)) = evazt(enfi)*(VELE_NF.L(enfi) + VELE_M_R.l(enfi))/(d0z(enfi)+m0z(enfi)); 
*	Nuclear primary energy
PrimEnergy(enfi)$(sameas(enfi,"enuc") and a0z(enfi))  = (1/nuceff)*evazt(enfi)*(VELE_NF.L(enfi) + VELE_M_R.l(enfi))/(d0z(enfi)+m0z(enfi)); 
*	Set primary enegry from fossil electricity sectors equal to zero (needed if a fossil sector is included as TSF technologies)
PrimEnergy("eoil") = 0;
PrimEnergy("egas") = 0;
PrimEnergy("ecol") = 0;
PrimEnergy("Total") = sum(enes,PrimEnergy(enes)); 

*	Note that values are in billions of 2011 dollars and emissions are in millions of metric tons
co2price = ((pco2.l*1e9/1e6)/pfx.l)$(policy("fclim") or policy("fctax"));
co2price_2 = ((pco2_2.l*1e9/1e6)/pfx.l)$policy("fclim_2");

*	Energy prices
EnegryPrice("Electricity") = pelec_s.l*(sum(ele,vomz(ele))*1e9)/(mtoe_TWh*sum(ele,evdpz(ele))*(1e12/1e3));
EnegryPrice("Crude oil") = pa.l("cru")*(sum(g,varmz("cru",g))*1e9)/(sum(g,(evdz("cru",g)+eviz("cru",g)))*mtoe_boe);

*	Prices and quantities
PDY(i) = p.l(i)/p.l("c");
DY(i) = VD0Z_R.l(i) + VX0Z_R.l(i);	
AY(i) =A0Z_R.L(i);
XY(i) = VX0Z_R.l(i);
MY(i) = M0Z_R.l(i);
intermediate(i,g) = VARMZ_R.L(i,g);	

*	Household transportation reporting
*	Fuel used in new cars
hhtrn("oil") = RPHT_OIL.l;
hhtrn("pt") = RPHT_PT.l;
*	Powertrain relative to oil		
hhtrn("pt_oil")$hhtrn("oil") = hhtrn("pt")/hhtrn("oil");
*	Oil relative to output
hhtrn("oil_output") = hhtrn("oil")/RMVH.l;
*	Non-powertrain capital
hhtrn("npt") = RPHT_NPT.l;

*	Share of powertrain-oil in transportation from new cars
shh_total("pt_oil") =	(vhhtz("pt","new") + vhhtz("oil","new"))
			/(vhhtz("npt","new") + vhhtz("ser","new") + vhhtz("pt","new") + vhhtz("oil","new"));
*	Share of powertrainin transportation from new cars
shh_total("pt") = vhhtz("pt","new")
			/(vhhtz("npt","new") + vhhtz("ser","new") + vhhtz("pt","new") + vhhtz("oil","new"));
*	Share of oil in transportation from new cars
shh_total("oil") = vhhtz("oil","new")
			/(vhhtz("npt","new") + vhhtz("ser","new") + vhhtz("pt","new") + vhhtz("oil","new"));

*	Share of powertrain in powertrain-oil aggregate
shh_pt_oil("pt") = RPHT_PT.l/(RPHT_PT.l + RPHT_OIL.l);
*	Share of powertrain in powertrain-oil aggregate
shh_pt_oil("oil") = RPHT_OIL.l/(RPHT_PT.l + RPHT_OIL.l);

shh_total("pt2") =  shh_total("pt_oil")*shh_pt_oil("pt");
shh_total("oil2") = shh_total("pt_oil")*shh_pt_oil("oil");
