* ====================================================================================================================
*	Inputs common to the reference and policy scenarios
* ====================================================================================================================
*	The target year
tyear = 2030;

*	GDP multiplier - annual growth rate to match GAP analysis
gdpmult = 1.0255**19;

*	Fossil fuel price multipliers
ffprice("col") = 1;	
ffprice("cru") = 2;	
ffprice("gas") = 1.1;

ffprice(g)$scenario("benchmark") = 0;

ffprice("gas") = 1.93;
ffprice("cru") = 1.02;

*	Technology specific factor multipliers in electricity generation
tsfmult("enuc") = 27.82/6.358;
tsfmult("ehyd") = 51.36/31.78;
tsfmult("eoil") = 3.56/19.726;
tsfmult("eoth") = 16/2.139;
tsfmult("eoth") = 2*gdpmult;
tsfmult("ewin") = gdpmult;
tsfmult("esol") = gdpmult;

tsfmult(etsf)$scenario("benchmark") = 1;

*	Electricity cost multiplier for sectors with technology specific factors
ecost(elea) = 1;
*	Adjust the cost of oil so that exogenous amounts can be forced in 
ecost("eoth") = 0.064526/0.094958;
ecost("eoil")  = 0.65;

ecost(elea)$scenario("benchmark") = 1;

*	Annual depreciation rate (by sector)
depre(g) = 0.05;
depre("ehyd") = 0;
depre("enuc") = 0;

*	Autonomous energy efficiency improvement multipliers - a value less than one indicates an efficiency improvement 
aeei_g(fe,g) = 0.015;
aeei_g(fe,efos) = 0.003;
aeei_g(fe,"eoil") = 0.003;
aeei_ely_g(g) = 0.015;

aeei(fe,g) = (1 - aeei_g(fe,g))**(tyear - 2011);
aeei_ely(g) = (1 - aeei_ely_g(g))**(tyear - 2011);

aeei("oil","trn") = 0.5; 
*	Set aeei for old vechiles 
aeei("oil","c_old") = aeei("oil","c");
aeei("oil","c_old") = 0.5;
*	Set aeei parameters equal to one in benchmark replication
aeei(i,g)$scenario("benchmark") = 1;
aeei_ely(g)$scenario("benchmark") = 1;
aeei("oil","c_old")$scenario("benchmark") = 1;

*	Income elasticity of demand for household transportation
*	Set the income elasticity
tran_y("elas") = 1;
*	Derive the multiplier on
tran_Y("mult") = (tran_y("elas")*gdpmult + 1)/(gdpmult + 1);
tran_Y("mult")$scenario("benchmark") = 1;

*	Scale CO2 emissions in the GTAP Database (set equal to one if no scaling is required)
co2scale(i,g) = 1;

*	Re-assign GHG emissoins (if desired)
*	Processed-based CO2 emissions assigned from BP (2015)
oghg("pco2","nmm") = 9.8;

*	Overwrite non-CO2 emissoins for some sectors (from the Gap Analysis)
oghg("ch4","agr") = 84.6;

*	Scale non-CO2 emissions
ghgmult(nco2,g) = 1;
ghgmult("fgas",g) = 1.8; 

*	Include automous reductions in other GHGS
ghgmult(nco2,g)$(scenario("benchmark") eq 0) = ghgmult(nco2,g)*(1-0.015)**(tyear - 2011);

*	Exogenous yield factor
yield(f,g) = 1;
yield(f,g)$(sameas(f,"lnd") or sameas(f,"res")) = (1+0.015)**(tyear - 2011);
yield(f,g)$scenario("benchmark") = 1;

*	Flags for Electricity and energy-intensive sectors
feint("enuc") = 1;
feint("ecoa") = 1;
feint("egas") = 1;
feint("ewin") = 1;
feint("esol") = 1;
feint("ehyd") = 1;
feint("eoil") = 1;
feint("eoth") = 1;
feint("oil") = 1;
feint("crp") = 1;
feint("nmm") = 1;
feint("i_s") = 1;
feint("nfm") = 1;
feint("gas") = 1;