$Title Parameters and calculation for household transportation

set z	Vehcile vintages	/old,new/;

*	Define parameters for household transportation
Parameters
tran_inputsz(*)	Inputs to specify private transportation
vhht_totalz	Total value of household transportation
vhhtz(*,z)	Value of inputs for household transportation
vnhhtz(i)	New vlaues for private consumption after substracting values for private transportation
ehht(*)		Elasticity value for household transportation;

*	See "Breaking out Household transportation.docx" for further notes and justification

*	Total refined oil for private transportation (Karplus thesis, page 202)
tran_inputsz("oil_tot") = 0.9;
*	Proportion of household transportation fuel used in new cars - see "Annual car running cost.xlsx"
tran_inputsz("oil_new") = 0.1182;
*	Share of new vehcile sales that is powertrain capital Figure A8b (p. 215) of Karlpus thesis - numbers for Japan
tran_inputsz("pt_new") = 0.2;
*	Services relative to refined oil purchase (same for old and new cars) from "Annual car running cost.xlsx"
tran_inputsz("services") = 1.337;
*	Proportion of powertrain-fuel aggregate that that must be powertrain in a fuel economy scenario
tran_inputsz("alpha") = 0.1;
tran_inputsz("alpha")$policy("f_alpha") = policy("f_alpha");

*	Assign values for refined oil purchases for new and old cars
vhhtz("oil","old") = varmz("oil","c")*tran_inputsz("oil_tot")*(1-tran_inputsz("oil_new"));
vhhtz("oil","new") = varmz("oil","c")*tran_inputsz("oil_tot")*tran_inputsz("oil_new");
vnhhtz("oil") = varmz("oil","c") - vhhtz("oil","old") - vhhtz("oil","new");

*	Assign expenditure on services for new and old cars
vhhtz("ser","old") = tran_inputsz("services")*vhhtz("oil","old"); 
vhhtz("ser","new") = tran_inputsz("services")*vhhtz("oil","new"); 
vnhhtz("ser") = varmz("ser","c") - vhhtz("ser","old") - vhhtz("ser","new");

*	Assign expenditure on powertrain and non-powertrain capital (new vehciles only)
vhhtz("pt","new") = varmz("mvh","c")*tran_inputsz("pt_new");
vhhtz("npt","new") = varmz("mvh","c")*(1-tran_inputsz("pt_new"));

*	Assign expenditure on new and old cars
vhhtz("output","old") = vhhtz("oil","old") + vhhtz("ser","old");
vhhtz("output","new") = vhhtz("oil","new") + vhhtz("ser","new") + varmz("mvh","c");

*	Assign the total value of private transportation
vhht_totalz = vhhtz("output","old") + vhhtz("output","new") + varmz("mvh","c") + varmz("trn","c");

varmz("ser","c") = vnhhtz("ser");

*	Assign transportation elasticity values
*	Elasticity of substitution between expenditure on old and new cars
ehht("o_n") = 0;
*	Elasticity of substitution between powertrain capital and fuel (from Karplus thesis, Figure 4.6c, p. 84)
*       The elasticity of supply of GHG emissions abatement = 0.225 and using equation (4.8)
ehht("pt_oil") = 0.225/(1 - (vhhtz("oil","new")/(vhhtz("oil","new") + vhhtz("pt","new"))));

*	Elasticity of substitution beween private (own-supplied) and commercial transportation (from Karplus thesis, Figure 1, p. 202) 
ehht("trn") = 0.5;

	